kedro.framework.cli — Kedro 0.17.6 documentation

# kedro.framework.cli

Description

`kedro.framework.cli` implements commands available from Kedro’s CLI.

Modules

`kedro.framework.cli.catalog` | A collection of CLI commands for working with Kedro catalog.
`kedro.framework.cli.cli` | kedro is a CLI for managing Kedro projects.
`kedro.framework.cli.hooks` | `kedro.framework.cli.hooks` provides primitives to use hooks to extend KedroCLI’s behaviour
`kedro.framework.cli.jupyter` | A collection of helper functions to integrate with Jupyter/IPython and CLI commands for working with Kedro catalog.
`kedro.framework.cli.pipeline` | A collection of CLI commands for working with Kedro pipelines.
`kedro.framework.cli.project` | A collection of CLI commands for working with Kedro project.
`kedro.framework.cli.registry` | A collection of CLI commands for working with registered Kedro pipelines.
`kedro.framework.cli.starters` | kedro is a CLI for managing Kedro projects.
`kedro.framework.cli.utils` | Utilities for use with click.